==> nativescript-0.2.0-471.tgz: package/lib/common/services/analytics-service.js <==
"use strict";
var util = require("util");

var helpers = require("./../helpers");
var options = require("./../options");
var os = require("os");
var xmlhttprequest = require("xmlhttprequest");

var AnalyticsService = (function () {
    function AnalyticsService($staticConfig, $logger, $errors, $prompter, $userSettingsService, $analyticsSettingsService) {
        this.$staticConfig = $staticConfig;
        this.$logger = $logger;
        this.$errors = $errors;
        this.$prompter = $prompter;
        this.$userSettingsService = $userSettingsService;
        this.$analyticsSettingsService = $analyticsSettingsService;
        this.excluded = ["help", "feature-usage-tracking"];
        this.analyticsStatus = null;
    }
    AnalyticsService.prototype.checkConsent = function (featureName) {
        var _this = this;
        return (function () {
            if (_this.$analyticsSettingsService.canRequestConsent().wait()) {
                if (_this.isNotConfirmed().wait() && helpers.isInteractive() && !_.contains(_this.excluded, featureName)) {
                    _this.$logger.out("Do you want to help us improve " + "Telerik".white.bold + " " + _this.$staticConfig.CLIENT_NAME.cyan.bold + " by automatically sending anonymous usage statistics? We will not use this information to identify or contact you." + " You can read our official Privacy Policy at");
                    var message = "http://www.telerik.com/company/privacy-policy";

                    var trackFeatureUsage = _this.$prompter.confirm(message, function () {
                        return "y";
                    }).wait();
                    _this.setAnalyticsStatus(trackFeatureUsage).wait();
                }
            }
        }).future()();
    };

    AnalyticsService.prototype.trackFeature = function (featureName) {
        var _this = this;
        return (function () {
            try  {
                _this.start().wait();

                if (_this._eqatecMonitor) {
                    var category = options.client || (helpers.isInteractive() ? "CLI" : "Non-interactive");
                    _this._eqatecMonitor.trackFeature(category + "." + featureName);
                }
            } catch (e) {
                _this.$logger.trace("Analytics exception: '%s'", e.toString());
            }
        }).future()();
    };

    AnalyticsService.prototype.trackException = function (exception, message) {
        var _this = this;
        return (function () {
            try  {
                _this.start().wait();

                if (_this._eqatecMonitor) {
                    _this._eqatecMonitor.trackException(exception, message);
                }
            } catch (e) {
                _this.$logger.trace("Analytics exception: '%s'", e.toString());
            }
        }).future()();
    };

    AnalyticsService.prototype.analyticsCommand = function (arg) {
        var _this = this;
        return (function () {
            switch (arg) {
                case "enable":
                    _this.setAnalyticsStatus(true).wait();
                    _this.$logger.info("Feature usage tracking is now enabled.");
                    break;
                case "disable":
                    _this.disableAnalytics().wait();
                    _this.$logger.info("Feature usage tracking is now disabled.");
                    break;
                case "status":
                case undefined:
                    _this.$logger.out(_this.getStatusMessage().wait());
                    break;
                default:
                    _this.$errors.fail("Invalid parameter");
                    break;
            }
        }).future()();
    };

    AnalyticsService.prototype.setAnalyticsStatus = function (enabled) {
        this.analyticsStatus = enabled ? 0 /* enabled */ : 1 /* disabled */;
        return this.$userSettingsService.saveSetting(this.$staticConfig.TRACK_FEATURE_USAGE_SETTING_NAME, enabled.toString());
    };

    AnalyticsService.prototype.getAnalyticsStatus = function () {
        var _this = this;
        return (function () {
            if (!_this.analyticsStatus) {
                var trackFeatureUsage = _this.$userSettingsService.getSettingValue(_this.$staticConfig.TRACK_FEATURE_USAGE_SETTING_NAME).wait();

                if (trackFeatureUsage) {
                    var isEnabled = helpers.toBoolean(trackFeatureUsage);
                    if (isEnabled) {
                        _this.analyticsStatus = 0 /* enabled */;
                    } else {
                        _this.analyticsStatus = 1 /* disabled */;
                    }
                } else {
                    _this.analyticsStatus = 2 /* notConfirmed */;
                }
            }

            return _this.analyticsStatus;
        }).future()();
    };

    AnalyticsService.prototype.start = function () {
        var _this = this;
        return (function () {
            if (_this._eqatecMonitor || _this.isDisabled().wait()) {
                return;
            }

            global.XMLHttpRequest = xmlhttprequest.XMLHttpRequest;
            global.userAgent = _this.getUserAgentString();

            require("../vendor/EqatecMonitor");

            var settings = global._eqatec.createSettings(_this.$staticConfig.ANALYTICS_API_KEY);
            settings.version = _this.$staticConfig.version;
            settings.loggingInterface = {
                logMessage: _this.$logger.trace.bind(_this.$logger),
                logError: _this.$logger.debug.bind(_this.$logger)
            };

            _this._eqatecMonitor = global._eqatec.createMonitor(settings);

            var guid = _this.$userSettingsService.getSettingValue(_this.$staticConfig.ANALYTICS_INSTALLATION_ID_SETTING_NAME).wait();
            if (!guid) {
                guid = require("node-uuid").v4();
                _this.$userSettingsService.saveSetting(_this.$staticConfig.ANALYTICS_INSTALLATION_ID_SETTING_NAME, guid).wait();
            }
            _this.$logger.trace("%s: %s", _this.$staticConfig.ANALYTICS_INSTALLATION_ID_SETTING_NAME, guid.toString());
            _this._eqatecMonitor.setInstallationID(guid);

            try  {
                _this._eqatecMonitor.setUserID(_this.$analyticsSettingsService.getUserId().wait());
            } catch (e) {
            }

            _this._eqatecMonitor.start();
        }).future()();
    };

    AnalyticsService.prototype.getUserAgentString = function () {
        var userAgentString;
        var osType = os.type();
        if (osType === "Windows_NT") {
            userAgentString = "(Windows NT " + os.release() + ")";
        } else if (osType === "Darwin") {
            userAgentString = "(Mac OS X " + os.release() + ")";
        }

        return userAgentString;
    };

    AnalyticsService.prototype.disableAnalytics = function () {
        var _this = this;
        return (function () {
            _this.setAnalyticsStatus(false).wait();

            if (_this._eqatecMonitor) {
                _this._eqatecMonitor.stop();
            }
        }).future()();
    };

    AnalyticsService.prototype.isDisabled = function () {
        var _this = this;
        return (function () {
            var analyticsStatus = _this.getAnalyticsStatus().wait();
            return analyticsStatus === 1 /* disabled */;
        }).future()();
    };

    AnalyticsService.prototype.isNotConfirmed = function () {
        var _this = this;
        return (function () {
            var analyticsStatus = _this.getAnalyticsStatus().wait();
            return analyticsStatus === 2 /* notConfirmed */;
        }).future()();
    };

    AnalyticsService.prototype.getStatusMessage = function () {
        if (options.json) {
            return this.getJsonStatusMessage();
        }

        return this.getHumanReadableStatusMessage();
    };

    AnalyticsService.prototype.getHumanReadableStatusMessage = function () {
        var _this = this;
        return (function () {
            var status = null;

            if (_this.isNotConfirmed().wait()) {
                status = "disabled until confirmed";
            } else {
                status = AnalyticsStatus[_this.getAnalyticsStatus().wait()];
            }

            return util.format("Feature usage tracking is %s.", status);
        }).future()();
    };

    AnalyticsService.prototype.getJsonStatusMessage = function () {
        var _this = this;
        return (function () {
            var status = _this.getAnalyticsStatus().wait();
            var enabled = status === 2 /* notConfirmed */ ? null : status === 1 /* disabled */ ? false : true;
            return JSON.stringify({ enabled: enabled });
        }).future()();
    };
    return AnalyticsService;
})();
exports.AnalyticsService = AnalyticsService;
$injector.register("analyticsService", AnalyticsService);

helpers.registerCommand("analyticsService", "feature-usage-tracking", function (analyticsService, args) {
    return analyticsService.analyticsCommand(args[0]);
});

var AnalyticsStatus;
(function (AnalyticsStatus) {
    AnalyticsStatus[AnalyticsStatus["enabled"] = 0] = "enabled";
    AnalyticsStatus[AnalyticsStatus["disabled"] = 1] = "disabled";
    AnalyticsStatus[AnalyticsStatus["notConfirmed"] = 2] = "notConfirmed";
})(AnalyticsStatus || (AnalyticsStatus = {}));

==> nativescript-0.3.1-18.tgz: package/lib/common/services/analytics-service.js <==
"use strict";
var util = require("util");

var helpers = require("../helpers");
var options = require("../options");
var os = require("os");
var xmlhttprequest = require("xmlhttprequest");

var AnalyticsService = (function () {
    function AnalyticsService($staticConfig, $logger, $errors, $prompter, $userSettingsService, $analyticsSettingsService) {
        this.$staticConfig = $staticConfig;
        this.$logger = $logger;
        this.$errors = $errors;
        this.$prompter = $prompter;
        this.$userSettingsService = $userSettingsService;
        this.$analyticsSettingsService = $analyticsSettingsService;
        this.excluded = ["help", "feature-usage-tracking"];
        this.analyticsStatus = null;
    }
    AnalyticsService.prototype.checkConsent = function (featureName) {
        var _this = this;
        return (function () {
            if (_this.$analyticsSettingsService.canDoRequest().wait()) {
                if (_this.isNotConfirmed().wait() && helpers.isInteractive() && !_.contains(_this.excluded, featureName)) {
                    _this.$logger.out("Do you want to help us improve " + "Telerik".white.bold + " " + _this.$staticConfig.CLIENT_NAME.cyan.bold + " by automatically sending anonymous usage statistics? We will not use this information to identify or contact you." + " You can read our official Privacy Policy at");
                    var message = "http://www.telerik.com/company/privacy-policy";

                    var trackFeatureUsage = _this.$prompter.confirm(message, function () {
                        return "y";
                    }).wait();
                    _this.setAnalyticsStatus(trackFeatureUsage).wait();
                }
            }
        }).future()();
    };

    AnalyticsService.prototype.trackFeature = function (featureName) {
        var _this = this;
        return (function () {
            if (_this.$analyticsSettingsService.canDoRequest().wait()) {
                try  {
                    _this.start().wait();
                    if (_this._eqatecMonitor) {
                        var category = options.client || (helpers.isInteractive() ? "CLI" : "Non-interactive");
                        _this._eqatecMonitor.trackFeature(category + "." + featureName);
                    }
                } catch (e) {
                    _this.$logger.trace("Analytics exception: '%s'", e.toString());
                }
            }
        }).future()();
    };

    AnalyticsService.prototype.trackException = function (exception, message) {
        var _this = this;
        return (function () {
            if (_this.$analyticsSettingsService.canDoRequest().wait()) {
                try  {
                    _this.start().wait();

                    if (_this._eqatecMonitor) {
                        _this._eqatecMonitor.trackException(exception, message);
                    }
                } catch (e) {
                    _this.$logger.trace("Analytics exception: '%s'", e.toString());
                }
            }
        }).future()();
    };

    AnalyticsService.prototype.analyticsCommand = function (arg) {
        var _this = this;
        return (function () {
            switch (arg) {
                case "enable":
                    _this.setAnalyticsStatus(true).wait();
                    _this.$logger.info("Feature usage tracking is now enabled.");
                    break;
                case "disable":
                    _this.disableAnalytics().wait();
                    _this.$logger.info("Feature usage tracking is now disabled.");
                    break;
                case "status":
                case undefined:
                    _this.$logger.out(_this.getStatusMessage().wait());
                    break;
                default:
                    _this.$errors.fail("Invalid parameter");
                    break;
            }
        }).future()();
    };

    AnalyticsService.prototype.setAnalyticsStatus = function (enabled) {
        this.analyticsStatus = enabled ? 0 /* enabled */ : 1 /* disabled */;
        return this.$userSettingsService.saveSetting(this.$staticConfig.TRACK_FEATURE_USAGE_SETTING_NAME, enabled.toString());
    };

    AnalyticsService.prototype.getAnalyticsStatus = function () {
        var _this = this;
        return (function () {
            if (!_this.analyticsStatus) {
                var trackFeatureUsage = _this.$userSettingsService.getSettingValue(_this.$staticConfig.TRACK_FEATURE_USAGE_SETTING_NAME).wait();

                if (trackFeatureUsage) {
                    var isEnabled = helpers.toBoolean(trackFeatureUsage);
                    if (isEnabled) {
                        _this.analyticsStatus = 0 /* enabled */;
                    } else {
                        _this.analyticsStatus = 1 /* disabled */;
                    }
                } else {
                    _this.analyticsStatus = 2 /* notConfirmed */;
                }
            }

            return _this.analyticsStatus;
        }).future()();
    };

    AnalyticsService.prototype.start = function () {
        var _this = this;
        return (function () {
            if (_this._eqatecMonitor || _this.isDisabled().wait()) {
                return;
            }

            global.XMLHttpRequest = xmlhttprequest.XMLHttpRequest;
            global.userAgent = _this.getUserAgentString();

            require("../vendor/EqatecMonitor");

            var settings = global._eqatec.createSettings(_this.$staticConfig.ANALYTICS_API_KEY);
            settings.version = _this.$staticConfig.version;
            settings.loggingInterface = {
                logMessage: _this.$logger.trace.bind(_this.$logger),
                logError: _this.$logger.debug.bind(_this.$logger)
            };

            _this._eqatecMonitor = global._eqatec.createMonitor(settings);

            var guid = _this.$userSettingsService.getSettingValue(_this.$staticConfig.ANALYTICS_INSTALLATION_ID_SETTING_NAME).wait();
            if (!guid) {
                guid = helpers.createGUID(false);
                _this.$userSettingsService.saveSetting(_this.$staticConfig.ANALYTICS_INSTALLATION_ID_SETTING_NAME, guid).wait();
            }
            _this.$logger.trace("%s: %s", _this.$staticConfig.ANALYTICS_INSTALLATION_ID_SETTING_NAME, guid.toString());
            _this._eqatecMonitor.setInstallationID(guid);

            try  {
                _this._eqatecMonitor.setUserID(_this.$analyticsSettingsService.getUserId().wait());
            } catch (e) {
            }

            _this._eqatecMonitor.start();
        }).future()();
    };

    AnalyticsService.prototype.getUserAgentString = function () {
        var userAgentString;
        var osType = os.type();
        if (osType === "Windows_NT") {
            userAgentString = "(Windows NT " + os.release() + ")";
        } else if (osType === "Darwin") {
            userAgentString = "(Mac OS X " + os.release() + ")";
        }

        return userAgentString;
    };

    AnalyticsService.prototype.disableAnalytics = function () {
        var _this = this;
        return (function () {
            _this.setAnalyticsStatus(false).wait();

            if (_this._eqatecMonitor) {
                _this._eqatecMonitor.stop();
            }
        }).future()();
    };

    AnalyticsService.prototype.isDisabled = function () {
        var _this = this;
        return (function () {
            var analyticsStatus = _this.getAnalyticsStatus().wait();
            return analyticsStatus === 1 /* disabled */;
        }).future()();
    };

    AnalyticsService.prototype.isNotConfirmed = function () {
        var _this = this;
        return (function () {
            var analyticsStatus = _this.getAnalyticsStatus().wait();
            return analyticsStatus === 2 /* notConfirmed */;
        }).future()();
    };

    AnalyticsService.prototype.getStatusMessage = function () {
        if (options.json) {
            return this.getJsonStatusMessage();
        }

        return this.getHumanReadableStatusMessage();
    };

    AnalyticsService.prototype.getHumanReadableStatusMessage = function () {
        var _this = this;
        return (function () {
            var status = null;

            if (_this.isNotConfirmed().wait()) {
                status = "disabled until confirmed";
            } else {
                status = AnalyticsStatus[_this.getAnalyticsStatus().wait()];
            }

            return util.format("Feature usage tracking is %s.", status);
        }).future()();
    };

    AnalyticsService.prototype.getJsonStatusMessage = function () {
        var _this = this;
        return (function () {
            var status = _this.getAnalyticsStatus().wait();
            var enabled = status === 2 /* notConfirmed */ ? null : status === 1 /* disabled */ ? false : true;
            return JSON.stringify({ enabled: enabled });
        }).future()();
    };
    return AnalyticsService;
})();
exports.AnalyticsService = AnalyticsService;
$injector.register("analyticsService", AnalyticsService);

helpers.registerCommand("analyticsService", "feature-usage-tracking", function (analyticsService, args) {
    return analyticsService.analyticsCommand(args[0]);
});

var AnalyticsStatus;
(function (AnalyticsStatus) {
    AnalyticsStatus[AnalyticsStatus["enabled"] = 0] = "enabled";
    AnalyticsStatus[AnalyticsStatus["disabled"] = 1] = "disabled";
    AnalyticsStatus[AnalyticsStatus["notConfirmed"] = 2] = "notConfirmed";
})(AnalyticsStatus || (AnalyticsStatus = {}));
